@@ -8,7 +8,7 @@ our @ISA = qw( Exporter );
 
 our @EXPORT = qw( LoadArgs LoadPatterns ClearPatterns Process );
 
-our $VERSION = "1.2";
+our $VERSION = "1.3";
 
 
 sub new
@@ -77,7 +77,6 @@ sub LoadArgs
                 $lastPatternOmitted = 1;
                 last SWITCH_ARGS;
             }
-            $bold ||= 0;    #make libvte happy (though xterm does not need it to be set explicitly)
             #populate patterns data
             if ( $ignorecase )
             {
@@ -195,29 +194,31 @@ sub InsertTags
                 if ( $tagtype eq "term" )
                 {
                     use integer;
+                    my $bold = ${ $$position[ 4 ] }->[ 2 ] || 22;
+                    # BEWARE: documentation says that escape sequences 39; and 49;
+                    # are not supported everywhere
+                    my ( $fgcolor, $bgcolor )= ( "39", "49" );
                     #color id in [0..15]
                     if ( ${ $$position[ 4 ] }->[ 1 ] < 16 && ${ $$position[ 4 ] }->[ 3 ] < 16 )
                     {
-                        my $fgcolor = ';3' . ${ $$position[ 4 ] }->[ 1 ] % 8 if defined
-                                        ${ $$position[ 4 ] }->[ 1 ];
-                        my $bgcolor = ${ $$position[ 4 ] }->[ 3 ] % 8 if defined
-                                        ${ $$position[ 4 ] }->[ 3 ];
-                        my $bold = ${ $$position[ 4 ] }->[ 1 ] / 8 if defined
-                                        ${ $$position[ 4 ] }->[ 1 ];
-                        #bold is ever 1 if bgcolor is set (xterm restriction)
-                        $bold = 1 if $bgcolor;
-                        $bold ||= ${ $$position[ 4 ] }->[ 2 ];
-                        $bgcolor = '4' . $bgcolor . ';' if defined $bgcolor;
-                        $colortag = qq/\033[$bgcolor$bold${fgcolor}m/;
+                        $fgcolor = "3" . ${ $$position[ 4 ] }->[ 1 ] % 8 if defined
+                                     ${ $$position[ 4 ] }->[ 1 ];
+                        $bgcolor = "4" . ${ $$position[ 4 ] }->[ 3 ] % 8 if defined
+                                     ${ $$position[ 4 ] }->[ 3 ];
+                        $bold = ${ $$position[ 4 ] }->[ 1 ] / 8 if defined
+                                     ${ $$position[ 4 ] }->[ 1 ];
+                        $bold ||= ${ $$position[ 4 ] }->[ 2 ] || 22;
                     }
                     #color id in [16..255]
                     else
                     {
-                        $colortag = qq/\033[${ $$position[ 4 ] }->[ 2 ];38;5;${ $$position[ 4 ] }->[ 1 ]m/
-                                        if ${ $$position[ 4 ] }->[ 1 ];
-                        $colortag .= qq/\033[48;5;${ $$position[ 4 ] }->[ 3 ]m/
-                                        if ${ $$position[ 4 ] }->[ 3 ];
+                        $fgcolor = "38;5;" . ${ $$position[ 4 ] }->[ 1 ] if defined
+                                     ${ $$position[ 4 ] }->[ 1 ];
+                        $bgcolor = "48;5;" . ${ $$position[ 4 ] }->[ 3 ] if defined
+                                     ${ $$position[ 4 ] }->[ 3 ];
                     }
+                    $bold .= ";" if defined $bold;
+                    $colortag = qq/\033[$bold$fgcolor;${bgcolor}m/;
                     last SWITCH_TAGTYPE;
                 }
                 if ( $tagtype eq "debug" || $tagtype eq "debug-term" )
@@ -310,11 +311,11 @@ on color terminals. It supports 256 color terminals and older
 =item B<LoadPatterns>
 
 expects reference to array of references to arrays of structure
-[ $pattern, $fg, $bold, $bg ]. Load patterns to be processed.
+[ $pattern, $fg, $bold, $bg ]. Loads patterns to be processed.
 
 =item B<ClearPatterns>
 
-clear loaded patterns.
+clears loaded patterns.
 
 =item B<LoadArgs>
 
@@ -325,7 +326,7 @@ Example of array to be loaded:
 
 =item B<Process>
 
-expects reference to string. Make substitution of color tags inside the
+expects reference to string. Makes substitution of color tags inside the
 string. Returns count of found matches.
 
 =back
@@ -340,7 +341,7 @@ A. Radkov, E<lt>alexey.radkov@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008 by A. Radkov.
+Copyright (C) 2008-2015 by A. Radkov.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
